@@ -21,6 +21,9 @@ func TestFoo6(t *testing.T) {
 			t.Errorf("%q. Foo6() error = %v, wantErr %v", tt.name, err, tt.wantErr)
 			continue
 		}
+		if tt.wantErr {
+			return
+		}
 		if got != tt.want {
 			t.Errorf("%q. Foo6() = %v, want %v", tt.name, got, tt.want)
 		}
